/**************************************************************************
    Souliss - Gateway for Expressif ESP8266 To RFM69
    
    Load this code on ESP8266 board using the porting of the Arduino core
    for this platform.
        
***************************************************************************/

// Let the IDE point to the Souliss framework
#include "SoulissFramework.h"

// Configure the framework
#include "bconf/MCU_ESP8266.h"              // Load the code directly on the ESP8266
#include "conf/Gateway.h"                   // The main node is the Gateway, we have just one node
#include "conf/IPBroadcast.h"
#include "conf/usart.h"

// **** Define the WiFi name and password ****
#define WIFICONF_INSKETCH
#define WiFi_SSID               "*****"
#define WiFi_Password           "*****"  

#define USARTBAUDRATE_INSKETCH
#define USART_BAUD19k2        1

// Include framework code and libraries
#include <ESP8266WiFi.h>
#include <EEPROM.h>
#include "Souliss.h"

// Define the network configuration according to your router settings
uint8_t ip_address[4]  = {192, 168, 0, 90};
uint8_t subnet_mask[4] = {255, 255, 255, 0};
uint8_t ip_gateway[4]  = {192, 168, 0, 20};

#define myvNet_address  ip_address[3]       // The last byte of the IP address (90) is also the vNet address

// This identify the number of the LED logic
#define MYLEDLOGIC          0

// **** Define here the right pin for your ESP module ****
#define  OUTPUTPIN     2

void setup()
{
  Initialize();
  Serial.begin(19200);

  // If fixed IP address is preferred, use below code
  // Set network parameters
  Souliss_SetIPAddress(ip_address, subnet_mask, ip_gateway);                          // Address on the Ethernet interface
  SetAsGateway(myvNet_address);
  
  // This is the vNet address for this node, used to communicate with other
  // nodes in your Souliss network
  SetAddress(0xAB01, 0xFF00, 0x0000);
  SetAddress(0xD002, 0xFF00, 0xD001);
  
  RoutingTable(0xD001, 0x6500, 0);
  
  SetAsPeerNode(0xD001, 1);
  SetAsPeerNode(0x6502, 2);
   
  Set_SimpleLight(MYLEDLOGIC);        // Define a simple LED light logic
  pinMode(OUTPUTPIN, OUTPUT);         // Use pin as output
}

void loop()
{
  // Here we start to play
  EXECUTEFAST() {
    UPDATEFAST();

    FAST_50ms() {   // We process the logic and relevant input and output every 50 milliseconds
      Logic_SimpleLight(MYLEDLOGIC);
      DigOut(OUTPUTPIN, Souliss_T1n_Coil, MYLEDLOGIC);
    }

    // Here we handle here the communication with Android
    FAST_GatewayComms();
  }
}
